@@ -32,6 +32,7 @@ pub(crate) mod non_critical_lints {
     pub mod prefer_regex_literals;
     pub mod quotes;
     pub mod radix;
+    pub mod use_is_nan;
     pub mod valid_typeof;
     pub mod yoda;
 }
@@ -139,6 +140,12 @@ pub fn all(lint_params: LintParams) -> Vec<Box<dyn Rule>> {
             &lint_config.no_new_symbol,
         ));
 
+        rules.extend(use_is_nan::use_is_nan(
+            program,
+            top_level_ctxt,
+            &lint_config.use_isnan,
+        ));
+
         rules.extend(valid_typeof::valid_typeof(&lint_config.valid_typeof));
     }
 
